@@ -38,7 +38,7 @@
 #include "md5.h"
 #include "xfuncs.h"
 
-#if defined HAVE_SHA256
+#if WITH_SHA256
 #include "sha256.h"
 #endif
 
@@ -96,6 +96,22 @@ int file_is_symlink(const char *file_name)
     return S_ISLNK(st.st_mode);
 }
 
+int file_is_symlink_to_dir(const char *file_name)
+{
+    int is_symlink_to_dir = 0;
+    if(file_is_symlink(file_name)) {
+        char *link_target;
+        struct stat target_stat;
+
+        link_target = realpath(file_name, NULL);
+        if (link_target) {
+            is_symlink_to_dir = (xlstat(link_target, &target_stat) == 0) && S_ISDIR(target_stat.st_mode);
+            free(link_target);
+        }
+    }
+    return is_symlink_to_dir;
+}
+
 char *file_readlink_alloc(const char *file_name)
 {
     struct stat st;
@@ -127,17 +143,14 @@ char *file_readlink_alloc(const char *file_name)
 */
 char *file_read_line_alloc(FILE * fp)
 {
+    size_t buf_len, line_size;
     char buf[BUFSIZ];
-    unsigned int buf_len;
     char *line = NULL;
-    unsigned int line_size = 0;
     int got_nl = 0;
 
-    buf[0] = '\0';
-
     while (fgets(buf, BUFSIZ, fp)) {
         buf_len = strlen(buf);
-        if (buf[buf_len - 1] == '\n') {
+        if (buf_len > 0 && buf[buf_len - 1] == '\n') {
             buf_len--;
             buf[buf_len] = '\0';
             got_nl = 1;
@@ -402,7 +415,7 @@ char *file_md5sum_alloc(const char *file_name)
     return md5_to_string(md5sum_bin);
 }
 
-#ifdef HAVE_SHA256
+#if WITH_SHA256
 char *file_sha256sum_alloc(const char *file_name)
 {
     int err;
