@@ -3,4 +3,4 @@ import os
 
 opkdir = "/tmp/opk"
 offline_root = "/tmp/opkg"
-opkgcl = os.getenv('OPKG_PATH', os.path.realpath("../src/opkg"))
+opkgcl = os.getenv('OPKG_PATH', os.path.realpath("../build/src/opkg"))
